@@ -137,10 +137,10 @@ It is supported from docker 18.09"
     (define-key menu-map [dfc]
       '(menu-item "Comment Region" comment-region
                   :help "Comment Region"))
-    (define-key menu-map [dfb]
+    (define-key-after menu-map [dfb]
       '(menu-item "Build" dockerfile-build-buffer
                   :help "Send the Dockerfile to docker build"))
-    (define-key menu-map [dfb]
+    (define-key-after menu-map [dfbnc]
       '(menu-item "Build without cache" dockerfile-build-no-cache-buffer
                   :help "Send the Dockerfile to docker build without cache"))
     map))
